@@ -1,5 +1,5 @@
 NLDoCommandWhile <-
-function(condition, ..., nl.obj=NULL)
+function(condition, ..., max.minutes=10, nl.obj=NULL)
 {
   if (is.null(nl.obj))
     nl.obj <- .rnetlogo[["nl.intern"]]
@@ -9,7 +9,7 @@ function(condition, ..., nl.obj=NULL)
   # put all commands together to one string to be evaluated by NetLogo
   command <- paste(commands, collapse=" ")
   
-  .jcall(nl.obj, "V", "doCommandWhile", .jnew("java/lang/String", command), .jnew("java/lang/String", condition))
+  .jcall(nl.obj, "V", "doCommandWhile", .jnew("java/lang/String", command), .jnew("java/lang/String", condition), .jnew("java/lang/Integer", as.integer(max.minutes)))  
   # java error handling
   if (!is.null(e<-.jgetEx()))
   {
